@@ -405,7 +405,8 @@ class Ppos(Module):
         return receive
 
     def getDelegateReward(self, from_address, node_ids=[]):
-        data = [rlp.encode(int(5100)), rlp.encode(bytes.fromhex(remove_0x_prefix(from_address))), rlp.encode(node_ids)]
+        node_id_bytes = [bytes.fromhex(node_id) for node_id in node_ids]
+        data = [rlp.encode(int(5100)), rlp.encode(bytes.fromhex(remove_0x_prefix(from_address))), rlp.encode(node_id_bytes)]
         data = rlp.encode(data)
         raw_data = call_obj(self, from_address, self.web3.delegateRewardAddress, data)
         receive = json.loads(str(raw_data, encoding="ISO-8859-1"))
